@@ -138,9 +138,12 @@ impl Listener {
             if let Ok((socket, node)) =
                 Listener::bootstrap(self.signaling, &self.table, &self.center)
             {
+                log::info!("actaeon bootstrap completed!");
                 let (conn, handler) = Connection::new(node.address, socket, self.cache.clone());
                 handler.spawn();
                 self.connections.borrow_mut().add(conn);
+            } else {
+                log::error!("actaeon bootstrap failed");
             }
             // TODO: Error handler
             loop {
@@ -163,6 +166,7 @@ impl Listener {
                 // 2. Read from TCP listener
                 match self.listener.accept() {
                     Ok((mut stream, _addr)) => {
+                        log::info!("new incoming TCP connection.");
                         if let Ok(node) = Handler::read_node(&mut stream) {
                             let _ = Handler::write_node(&mut stream, &self.center);
                             let addr = node.address.clone();
@@ -173,9 +177,7 @@ impl Listener {
                         }
                         // if any of the steps fail the connection gets dropped.
                     }
-                    Err(_) => {
-                        log::error!("unable to handle incoming TCP connection.");
-                    }
+                    Err(_) => {}
                 }
 
                 // 3. Read from Connection channels
@@ -305,6 +307,7 @@ impl Handler {
             loop {
                 // Incoming TCP
                 if let Ok(wire) = Handler::read_wire(&mut self.socket) {
+                    log::info!("received message through existing connection.");
                     if !self.cache.exists(&wire.uuid) || wire.is_empty() {
                         self.cache.add(&wire.uuid);
                         let _ = self.channel.send(Action::Message(wire));
